@@ -208,6 +208,20 @@
 #define STATUS_CODES_LABEL             \
   N_("Status Codes")
 
+#define MIME_TYPE_HEAD                 \
+  N_("MIME Types")
+#define MIME_TYPE_DESC                 \
+  N_("File types shipped out")
+#define MIME_TYPE_LABEL                \
+  N_("MIME Types")
+
+#define TLS_TYPE_HEAD				\
+  N_("Encryption settings")
+#define TLS_TYPE_DESC                 \
+  N_("TLS version and picked algorithm")
+#define TLS_TYPE_LABEL                \
+  N_("TLS Settings")
+
 /* Find Labels */
 #define CISENSITIVE                    \
   _("[ ] case sensitive")
@@ -287,6 +301,8 @@
   _("Select a log format.")
 #define ERR_PANEL_DISABLED             \
   _("'%1$s' panel is disabled")
+#define ERR_NO_DATA_PASSED             \
+  _("No input data was provided nor there's data to restore.")
 
 /* Other */
 #define INFO_MORE_INFO                 \
