@@ -37,6 +37,7 @@
 
 #include "opesys.h"
 
+#include "error.h"
 #include "settings.h"
 #include "util.h"
 #include "xmalloc.h"
@@ -90,6 +91,7 @@ static const char *os[][2] = {
   {"CentOS", "Linux"},
   {"PCLinuxOS", "Linux"},
   {"Linux", "Linux"},
+  {"linux", "Linux"},
 
   {"FreeBSD", "BSD"},
   {"NetBSD", "BSD"},
@@ -392,5 +394,8 @@ verify_os (const char *str, char *os_type) {
   }
   xstrncpy (os_type, "Unknown", OPESYS_TYPE_LEN);
 
+  if (conf.unknowns_log)
+    LOG_UNKNOWNS (("%-7s%s\n", "[OS]", str));
+
   return alloc_string ("Unknown");
 }
