@@ -70,18 +70,18 @@ static const GPreConfLog logs = {
   "%h %^[%d:%t %^] \"%r\" %s %b",                               /* CLF */
   "%v:%^ %h %^[%d:%t %^] \"%r\" %s %b",                         /* CLF+VHost */
   "%d %t %^ %m %U %q %^ %^ %h %u %R %s %^ %^ %L",               /* W3C */
-  "%d\\t%t\\t%^\\t%b\\t%h\\t%m\\t%^\\t%r\\t%s\\t%R\\t%u\\t%^",  /* CloudFront */
+  "%d\\t%t\\t%^\\t%b\\t%h\\t%m\\t%v\\t%U\\t%s\\t%R\\t%u\\t%q\\t%^\\t%C\\t%^\\t%^\\t%^\\t%^\\t%T\\t%^\\t%K\\t%k\\t%^\\t%H\\t%^",  /* CloudFront */
   "\"%x\",\"%h\",%^,%^,\"%m\",\"%U\",\"%s\",%^,\"%b\",\"%D\",%^,\"%R\",\"%u\"", /* Cloud Storage */
   "%^ %dT%t.%^ %v %h:%^ %^ %T %^ %^ %s %^ %b %^ \"%r\" \"%u\" %^",    /* AWS Elastic Load Balancing */
   "%^ %^ %^ %v %^: %x.%^ %~%L %h %^/%s %b %m %U",               /* Squid Native */
   "%^ %v [%d:%t %^] %h %^\"%r\" %s %^ %b %^ %L %^ \"%R\" \"%u\"", /* Amazon S3 */
 
   /* Caddy JSON */
-  "{\"ts\":\"%x.%^\",\"request\":{\"remote_addr\":\"%h:%^\",\"proto\":\"%H\","
-    "\"method\":\"%m\",\"host\":\"%v\",\"uri\":\"%U\","
-    "\"headers\":{\"User-Agent\":[\"%u\"]},\"tls\":{\"cipher_suite\":\"%k\","
-    "\"proto\":\"%K\"}},\"duration\":\"%T\",\"size\":\"%b\",\"status\":\"%s\","
-    "\"resp_headers\":{\"Content-Type\":[\"%M\"]}}"
+  "{ \"ts\": \"%x.%^\", \"request\": { \"remote_addr\": \"%h:%^\", \"proto\":"
+  "\"%H\", \"method\": \"%m\", \"host\": \"%v\", \"uri\": \"%U\", \"headers\": {"
+  "\"User-Agent\": [\"%u\"], \"Referer\": [\"%R\"] }, \"tls\": { \"cipher_suite\":"
+  "\"%k\", \"proto\": \"%K\" } }, \"duration\": \"%T\", \"size\": \"%b\","
+  "\"status\": \"%s\", \"resp_headers\": { \"Content-Type\": [\"%M\"] } }"
 };
 
 static const GPreConfTime times = {
@@ -699,6 +699,8 @@ is_json_log_format (const char *fmt) {
   json_stream json;
 
   json_open_string (&json, fmt);
+  /* ensure we use strict JSON when determining if we're using a JSON format */
+  json_set_streaming (&json, false);
   do {
     t = json_next (&json);
     switch (t) {
@@ -803,7 +805,7 @@ parse_json_string (void *ptr_data, const char *str, int (*cb) (void *, char *, c
         ws_append_str (&key, json_get_string (&json, &len));
       }
       /* val */
-      else if (ctx == JSON_ARRAY || ((level % 2) == 0 && ctx != JSON_ARRAY)) {
+      else if (key && (ctx == JSON_ARRAY || ((level % 2) == 0 && ctx != JSON_ARRAY))) {
         val = xstrdup (json_get_string (&json, &len));
         if ((ret = (*cb) (ptr_data, key, val)))
           goto clean;
